==> libreoffice-fresh-sdk-24.8.4-2-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.js <==
var servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel =
[
    [ "UnoControlModel", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#ac1ee7df8246117083090d716cae44bb0", null ],
    [ "BackgroundColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a85c9847c6ec77e673c618e26b2aa0746", null ],
    [ "Border", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a54d3ff280d892218d71e667f81ce99d4", null ],
    [ "BorderColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a79f9492eb784a2ae0323d4d31b179a8a", null ],
    [ "Date", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a98095e2c3547bb3d5a70bc3d82dd3350", null ],
    [ "DateFormat", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#af22ba491abba9735497b4f0abccdfedf", null ],
    [ "DateMax", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a723ebc9682359b89df230d9fe11edc52", null ],
    [ "DateMin", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a5658fb6d5e168156de97096242f5af3d", null ],
    [ "DateShowCentury", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a0c7be7dfbbffa80455e5b2cb4928710f", null ],
    [ "Dropdown", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a8ea656cd794526900f226d0666d8c173", null ],
    [ "Enabled", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#add0e09d5a83268ea58802b8b35fb4dfa", null ],
    [ "FontDescriptor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a9e110c55c0a3426a353ded5f029cd4e0", null ],
    [ "FontEmphasisMark", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#ac5c5781ab84a14cafec66b192fbdeae9", null ],
    [ "FontRelief", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#ac2b8dcc269c9ef6d27978db9b76caa43", null ],
    [ "HelpText", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a7e52ef40b5265c017585bf7d607ee31a", null ],
    [ "HelpURL", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a755e2d2c27383c5201ee98aaed028954", null ],
    [ "HideInactiveSelection", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a4a7a3ff65ecc704925e4c0692da1baa1", null ],
    [ "HighlightColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a9f6d16e9f74137fc9e3158e8928c8572", null ],
    [ "HighlightTextColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a9b462e58b5c1c9058cd57041eb9c83e2", null ],
    [ "MouseWheelBehavior", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#aa612def382bea69d1c4e47f279268ae2", null ],
    [ "Printable", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#ad75a741ee6d8f45340ba0bbb7771f05b", null ],
    [ "ReadOnly", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a27f7199b1316915a80fec16a3c215148", null ],
    [ "Repeat", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a5129b8c2bd73916407e626738bd0136b", null ],
    [ "RepeatDelay", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a4e2dfbf3068c08b49a036a8490722569", null ],
    [ "Spin", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#aa8dba34cfd2b192cdd8af7876ac3fc03", null ],
    [ "StrictFormat", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a98fd1071b232d41231a91eb0bb3ac4b2", null ],
    [ "Tabstop", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a58b62919451b71e65ecb718a57c053e5", null ],
    [ "Text", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#ab4726c7c06ae41233e679361293b4173", null ],
    [ "TextColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a01c58818488ca5e1d235d71b625efa0e", null ],
    [ "TextLineColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a7de6f39eb42c328f77d4db6f6861bd6b", null ],
    [ "VerticalAlign", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#aeeee894b4f8f059ee92ccef71579845a", null ],
    [ "WritingMode", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a002026db708f25e491f177b8f102f172", null ]
];

==> libreoffice-fresh-sdk-25.8.4-3-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.js <==
var servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel =
[
    [ "com::sun::star::awt::UnoControlModel", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#ac1ee7df8246117083090d716cae44bb0", null ],
    [ "BackgroundColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a85c9847c6ec77e673c618e26b2aa0746", null ],
    [ "Border", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a54d3ff280d892218d71e667f81ce99d4", null ],
    [ "BorderColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a79f9492eb784a2ae0323d4d31b179a8a", null ],
    [ "Date", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a98095e2c3547bb3d5a70bc3d82dd3350", null ],
    [ "DateFormat", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#af22ba491abba9735497b4f0abccdfedf", null ],
    [ "DateMax", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a723ebc9682359b89df230d9fe11edc52", null ],
    [ "DateMin", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a5658fb6d5e168156de97096242f5af3d", null ],
    [ "DateShowCentury", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a0c7be7dfbbffa80455e5b2cb4928710f", null ],
    [ "Dropdown", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a8ea656cd794526900f226d0666d8c173", null ],
    [ "Enabled", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#add0e09d5a83268ea58802b8b35fb4dfa", null ],
    [ "FontDescriptor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a9e110c55c0a3426a353ded5f029cd4e0", null ],
    [ "FontEmphasisMark", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#ac5c5781ab84a14cafec66b192fbdeae9", null ],
    [ "FontRelief", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#ac2b8dcc269c9ef6d27978db9b76caa43", null ],
    [ "HelpText", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a7e52ef40b5265c017585bf7d607ee31a", null ],
    [ "HelpURL", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a755e2d2c27383c5201ee98aaed028954", null ],
    [ "HideInactiveSelection", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a4a7a3ff65ecc704925e4c0692da1baa1", null ],
    [ "HighlightColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a9f6d16e9f74137fc9e3158e8928c8572", null ],
    [ "HighlightTextColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a9b462e58b5c1c9058cd57041eb9c83e2", null ],
    [ "MouseWheelBehavior", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#aa612def382bea69d1c4e47f279268ae2", null ],
    [ "Printable", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#ad75a741ee6d8f45340ba0bbb7771f05b", null ],
    [ "ReadOnly", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a27f7199b1316915a80fec16a3c215148", null ],
    [ "Repeat", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a5129b8c2bd73916407e626738bd0136b", null ],
    [ "RepeatDelay", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a4e2dfbf3068c08b49a036a8490722569", null ],
    [ "Spin", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#aa8dba34cfd2b192cdd8af7876ac3fc03", null ],
    [ "StrictFormat", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a98fd1071b232d41231a91eb0bb3ac4b2", null ],
    [ "Tabstop", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a58b62919451b71e65ecb718a57c053e5", null ],
    [ "Text", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#ab4726c7c06ae41233e679361293b4173", null ],
    [ "TextColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a01c58818488ca5e1d235d71b625efa0e", null ],
    [ "TextLineColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a7de6f39eb42c328f77d4db6f6861bd6b", null ],
    [ "VerticalAlign", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#aeeee894b4f8f059ee92ccef71579845a", null ],
    [ "WritingMode", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDateFieldModel.html#a002026db708f25e491f177b8f102f172", null ]
];
